RepoScraper
============

A REST API which uses the Python package ``codesurvey`` behind the
scenes to sample git repositories and return results about language
features. Uses OpenAPI 3.0 for documentation.

Running
-------

When deploying RepoScraper, pass a filename to the database as a single
argument where you want results to be saved. Once running, you can
find OpenAPI specification under the path: ``/apidocs``.

Contact
-------

For any questions or feedback, reach out to me via my email:
elliot@p-s.co.nz
